"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _path = require("path");
var _utils = require("../../utils");
var newUtils = _interopRequireWildcard(require("../utils"));
var legacyUtils = _interopRequireWildcard(require("../legacyUtils"));
const isLegacyKey = key => {
  return !key.includes("/");
};
var _default = {
  canProcess: params => {
    const {
      key,
      extension
    } = params;
    const utils = key.includes("/") ? newUtils : legacyUtils;
    if (!utils.SUPPORTED_IMAGES.includes(extension)) {
      return false;
    }

    // We only want to process original images, and delete all variations of it at once.
    // We DO NOT want to process the event for the deletion of an optimized/transformed image.
    // Unfortunately, there's no way to filter those events on the S3 bucket itself, so we have to do it this way.
    return !(key.startsWith(utils.OPTIMIZED_IMAGE_PREFIX) || key.startsWith(utils.OPTIMIZED_TRANSFORMED_IMAGE_PREFIX));
  },
  async process({
    s3,
    key,
    extension
  }) {
    const utils = key.includes("/") ? newUtils : legacyUtils;

    // 1. Get optimized image key.
    await s3.deleteObject((0, _utils.getObjectParams)(utils.getImageKey({
      key
    }))).promise();
    if (!utils.SUPPORTED_TRANSFORMABLE_IMAGES.includes(extension)) {
      return;
    }

    /**
     * Search for all transformed images and delete those too.
     *
     * For new keys, we take the entire path, up to, but not including, the file name:
     *  - demo-pages/60228148f98841000981c724/welcome-to-webiny__idp.svg
     *  - 60228148f98841000981c724/welcome-to-webiny__idp.svg
     *
     * Legacy keys don't have sub-folders:
     *  - 8ldc5n3w2-custom-field-renderers.mp4
     */

    const prefix = isLegacyKey(key) ? utils.getOptimizedImageKeyPrefix(key) : (0, _path.dirname)(key) + "/";
    const env = (0, _utils.getEnvironment)();
    const imagesList = await s3.listObjects({
      Bucket: env.bucket,
      Prefix: prefix
    }).promise();
    if (!imagesList.Contents) {
      return;
    }
    for (const imageObject of imagesList.Contents) {
      if (!imageObject.Key) {
        continue;
      }
      await s3.deleteObject((0, _utils.getObjectParams)(imageObject.Key)).promise();
    }
  }
};
exports.default = _default;